pub struct Projector<P, S> where
    P: Projection
{ /* private fields */ }
A Projector manages the state of a single Projection by opening a long-running stream of all events coming from the EventStore.

New instances of a Projector are obtainable through a ProjectorBuilder instance.

The Projector will start updating the Projection state when run is called.

At each update, the Projector will broadcast the latest version of the Projection on a Stream obtainable through watch.

Implementations

Create a new Projector from the provided Projection and Subscription values.

Starts the update of the Projection by processing all the events coming from the EventStore.