Module eventually_util::inmemory
source · [−]Expand description
Contains supporting entities using an in-memory backend.
Structs
Error returned by the EventStore::append when a conflict has been detected.
An in-memory EventStore implementation, backed by an HashMap.
Builder for EventStore instances.
A Projector manages the state of a single Projection
by opening a long-running stream of all events coming from the EventStore.
Error returned by the EventSubscriber when reading elements
from the EventStream produced by subscribe_all.